@@ -28,6 +28,7 @@ class DiscoverObject : public QObject
     Q_PROPERTY(bool isRoot READ isRoot CONSTANT)
     Q_PROPERTY(QQuickWindow *mainWindow READ mainWindow CONSTANT)
     Q_PROPERTY(InlineMessage *homePageMessage READ homePageMessage NOTIFY homeMessageChanged)
+    Q_PROPERTY(int sidebarWidth READ sidebarWidth WRITE setSidebarWidth NOTIFY sidebarWidthChanged)
 
 public:
     explicit DiscoverObject(const QVariantMap &initialProperties);
@@ -51,6 +52,9 @@ public:
     Q_SCRIPTABLE void restore();
     [[nodiscard]] InlineMessage *homePageMessage() const;
 
+    int sidebarWidth() const;
+    void setSidebarWidth(int width);
+
     Q_SCRIPTABLE bool quitWhenIdle();
 
 public Q_SLOTS:
@@ -78,6 +82,7 @@ Q_SIGNALS:
     void
     openErrorPage(const QString &errorMessage, const QString &errorExplanation, const QString &buttonText, const QString &buttonIcon, const QString &buttonURL);
     void homeMessageChanged();
+    void sidebarWidthChanged(int width);
 
 private:
     void showLoadingPage();
@@ -95,4 +100,6 @@ private:
     std::unique_ptr<CachedNetworkAccessManagerFactory> m_networkAccessManagerFactory;
     std::unique_ptr<KStatusNotifierItem, QScopedPointerDeleteLater> m_sni;
     std::unique_ptr<InlineMessage> m_homePageMessage;
+
+    bool m_isDeleting = false;
 };
