@@ -49,10 +49,7 @@ public:
     ResultsStream *search(const AbstractResourcesBackend::Filters &search) override;
     ResultsStream *findResourceByPackageName(const QUrl &search);
     bool isValid() const override;
-    int fetchingUpdatesProgress() const override
-    {
-        return m_isFetching > 0 ? 42 : 100;
-    }
+    int fetchingUpdatesProgress() const override;
 
     Transaction *installApplication(AbstractResource *app) override;
     Transaction *installApplication(AbstractResource *app, const AddonList &addons) override;
