@@ -52,6 +52,7 @@
 #include "libdiscover_backend_packagekit_debug.h"
 #include "utils.h"
 #include <Category/Category.h>
+#include <Category/CategoryModel.h>
 #include <resources/ResourcesModel.h>
 
 using namespace std::chrono_literals;
@@ -128,23 +129,12 @@ Delay::Delay()
 
 PackageKitBackend::PackageKitBackend(QObject *parent)
     : AbstractResourcesBackend(parent)
-    , m_appdata(new AppStream::Pool)
+    , m_appdata(new AppStream::ConcurrentPool)
     , m_updater(new PackageKitUpdater(this))
     , m_refresher(nullptr)
     , m_isFetching(0)
     , m_reviews(OdrsReviewsBackend::global())
-    , m_reportToDistroAction(
-          new DiscoverAction(u"tools-report-bug-symbolic"_s,
-                             i18nc("@action:button %1 is the distro name", "Report This Issue to %1", AppStreamIntegration::global()->osRelease()->name()),
-                             this))
 {
-    connect(m_reportToDistroAction, &DiscoverAction::triggered, this, [] {
-        const auto url = QUrl(AppStreamIntegration::global()->osRelease()->bugReportUrl());
-        if (!QDesktopServices::openUrl(url)) {
-            qCWarning(LIBDISCOVER_BACKEND_PACKAGEKIT_LOG) << "Failed to open bug report url" << url;
-        }
-    });
-
     QTimer *t = new QTimer(this);
     connect(t, &QTimer::timeout, this, &PackageKitBackend::checkForUpdates);
     t->setInterval(60 * 60 * 1000);
@@ -152,7 +142,7 @@ PackageKitBackend::PackageKitBackend(QObject *parent)
     t->start();
 
     connect(&m_details, &Delay::perform, this, &PackageKitBackend::performDetailsFetch);
-    connect(&m_details, &Delay::perform, this, [this](const QSet<QString> &pkgids) {
+    connect(&m_updateDetails, &Delay::perform, this, [this](const QSet<QString> &pkgids) {
         PackageKit::Transaction *t = PackageKit::Daemon::getUpdatesDetails(kSetToList(pkgids));
         connect(t,
                 &PackageKit::Transaction::updateDetail,
@@ -237,6 +227,28 @@ PackageKitBackend::PackageKitBackend(QObject *parent)
 
     m_globalHints = QStringList() << QStringLiteral("interactive=true") << QStringLiteral("locale=%1").arg(qEnvironmentVariable("LANG"));
     PackageKit::Daemon::global()->setHints(m_globalHints);
+
+    // Hide the drivers category if there's no drivers
+    connect(CategoryModel::global(), &CategoryModel::rootCategoriesChanged, this, [this] {
+        auto driversCategory = CategoryModel::global()->findCategoryByName(QStringLiteral("Hardware Drivers"));
+
+        // Will be null on subsequent runs
+        if (!driversCategory) {
+            return;
+        }
+
+        AbstractResourcesBackend::Filters filter;
+        filter.category = driversCategory;
+        auto stream = search(filter);
+        connect(stream, &ResultsStream::resourcesFound, stream, [stream] {
+            stream->setProperty("foundDrivers", true);
+        });
+        connect(stream, &ResultsStream::destroyed, stream, [stream, driversCategory] {
+            if (!stream->property("foundDrivers").toBool()) {
+                driversCategory->hide();
+            }
+        });
+    });
 }
 
 PackageKitBackend::~PackageKitBackend()
@@ -291,11 +303,6 @@ void PackageKitBackend::updateProxy()
     }
 }
 
-bool PackageKitBackend::isFetching() const
-{
-    return m_isFetching;
-}
-
 void PackageKitBackend::acquireFetching(bool f)
 {
     if (f) {
@@ -304,11 +311,10 @@ void PackageKitBackend::acquireFetching(bool f)
         m_isFetching--;
     }
 
-    if ((!f && m_isFetching == 0) || (f && m_isFetching == 1)) {
-        Q_EMIT fetchingChanged();
-        if (m_isFetching == 0) {
-            Q_EMIT available();
-        }
+    if (!f && m_isFetching == 0) {
+        Q_EMIT contentsChanged();
+        Q_EMIT available();
+        Q_EMIT updatesCountChanged();
     }
     Q_ASSERT(m_isFetching >= 0);
 }
@@ -317,7 +323,7 @@ void PackageKitBackend::reloadPackageList()
 {
     acquireFetching(true);
 
-    m_appdata.reset(new AppStream::Pool);
+    m_appdata->reset(new AppStream::Pool, &m_threadPool);
 
     const auto loadDone = [this](bool correct) {
         if (!correct && m_packages.packages.isEmpty()) {
@@ -340,10 +346,10 @@ void PackageKitBackend::reloadPackageList()
         acquireFetching(false);
 
         const auto distroComponents = m_appdata->componentsById(AppStream::SystemInfo::currentDistroComponentId());
-        if (distroComponents.isEmpty()) {
+        if (distroComponents.result().isEmpty()) {
             qWarning() << "PackageKitBackend: No distro component found for" << AppStream::SystemInfo::currentDistroComponentId();
         }
-        for (const AppStream::Component &dc : distroComponents) {
+        for (const AppStream::Component &dc : distroComponents.result()) {
             const auto releases = dc.releasesPlain().entries();
             for (const auto &r : releases) {
                 int cmp = AppStream::Utils::vercmpSimple(r.version(), AppStreamIntegration::global()->osRelease()->versionId());
@@ -366,7 +372,7 @@ void PackageKitBackend::reloadPackageList()
         }
     };
 
-    connect(m_appdata.get(), &AppStream::Pool::loadFinished, this, [this, loadDone](bool success) {
+    connect(m_appdata.get(), &AppStream::ConcurrentPool::loadFinished, this, [this, loadDone](bool success) {
         m_appdataLoaded = true;
         if (!success) {
             qWarning() << "PackageKitBackend: Could not open the AppStream metadata pool" << m_appdata->lastError();
@@ -565,7 +571,7 @@ T PackageKitBackend::resourcesByPackageNames(const W &pkgnames) const
                 if (resource) {
                     ret += resource;
                 } else {
-                    ret += resourcesByComponents<T>(m_appdata->componentsByBundleId(AppStream::Bundle::KindPackage, pkg_name, false));
+                    ret += resourcesByComponents<T>(m_appdata->componentsByBundleId(AppStream::Bundle::KindPackage, pkg_name, false).result());
                 }
             }
         }
@@ -582,6 +588,7 @@ void PackageKitBackend::checkForUpdates()
 
     if (!m_refresher) {
         acquireFetching(true);
+        Q_EMIT m_updater->fetchingChanged();
         m_updater->clearDistroUpgrade();
         m_refresher = PackageKit::Daemon::refreshCache(false);
         // Limit the cache-age so that we actually download new caches if necessary
@@ -593,6 +600,7 @@ void PackageKitBackend::checkForUpdates()
             m_refresher = nullptr;
             fetchUpdates();
             acquireFetching(false);
+            Q_EMIT m_updater->fetchingChanged();
         });
     } else {
         qWarning() << "PackageKitBackend: Already resetting";
@@ -605,10 +613,10 @@ AppStream::ComponentBox PackageKitBackend::componentsById(const QString &id) con
 {
     Q_ASSERT(m_appstreamInitialized);
     auto comps = m_appdata->componentsById(id);
-    if (comps.isEmpty()) {
+    if (comps.result().isEmpty()) {
         comps = m_appdata->componentsByProvided(AppStream::Provided::KindId, id);
     }
-    return comps;
+    return comps.result();
 }
 
 static bool needsResolveFilter(const StreamResult &result)
@@ -623,6 +631,7 @@ private:
         : ResultsStream(name)
         , backend(backend)
     {
+        Q_ASSERT(QThread::currentThread() == backend->thread());
     }
 
     PKResultsStream(PackageKitBackend *backend, const QString &name, const QVector<StreamResult> &resources)
@@ -649,6 +658,7 @@ public:
         }
 
         Q_ASSERT(resources.size() == QSet(resources.constBegin(), resources.constEnd()).size());
+        Q_ASSERT(QThread::currentThread() == backend->thread());
         const auto toResolve = kFilter<QVector<StreamResult>>(resources, needsResolveFilter);
         if (!toResolve.isEmpty()) {
             auto transaction = backend->resolvePackages(kTransform<QStringList>(toResolve, [](const StreamResult &result) {
@@ -703,9 +713,10 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
         return findResourceByPackageName(filter.resourceUrl);
     } else if (!filter.extends.isEmpty()) {
         return deferredResultStream(u"PackageKitStream-extends"_s, [this, filter = filter](PKResultsStream *stream) {
-            const auto extendingComponents = m_appdata->componentsByExtends(filter.extends);
-            auto resources = resultsByComponents(extendingComponents);
-            stream->sendResources(resources, filter.state != AbstractResource::Broken);
+            m_appdata->componentsByExtends(filter.extends).then(this, [this, stream, filter](const QFuture<AppStream::ComponentBox> &extendingComponents) {
+                auto resources = resultsByComponents(extendingComponents.result());
+                stream->sendResources(resources, filter.state != AbstractResource::Broken);
+            });
         });
     } else if (filter.state == AbstractResource::Upgradeable) {
         return new ResultsStream(QStringLiteral("PackageKitStream-upgradeable"),
@@ -773,19 +784,25 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
         });
     } else {
         return deferredResultStream(u"PackageKitStream-search"_s, [this, filter = filter](PKResultsStream *stream) {
-            auto loadComponents = [](const auto &filter, const auto &appdata) -> QCoro::Task<AppStream::ComponentBox> {
-                AppStream::ComponentBox components(AppStream::ComponentBox::FlagNone);
+            auto loadComponents = [](const auto &filter, const auto &appdata) -> QFuture<AppStream::ComponentBox> {
+                QFuture<AppStream::ComponentBox> components;
                 if (!filter.search.isEmpty()) {
                     components = appdata->search(filter.search);
                 } else if (filter.category) {
-                    components = co_await AppStreamUtils::componentsByCategoriesTask(appdata.get(), filter.category, AppStream::Bundle::KindUnknown);
+                    components = AppStreamUtils::componentsByCategoriesTask(appdata.get(), filter.category, AppStream::Bundle::KindUnknown);
                 } else {
                     components = appdata->components();
                 }
-                co_return components;
+                return components;
             };
-            QCoro::connect(loadComponents(filter, m_appdata), this, [this, stream, filter](auto &&components) {
+
+            auto watcher = new QFutureWatcher<AppStream::ComponentBox>();
+            auto futureComponents = loadComponents(filter, m_appdata);
+            watcher->setFuture(futureComponents);
+            connect(watcher, &QFutureWatcher<AppStream::ComponentBox>::finished, watcher, &QObject::deleteLater);
+            connect(watcher, &QFutureWatcher<AppStream::ComponentBox>::finished, stream, [this, stream, filter, futureComponents]() {
                 QSet<QString> ids;
+                AppStream::ComponentBox components = futureComponents.result();
                 kFilterInPlace<AppStream::ComponentBox>(components, [&ids](const AppStream::Component &component) {
                     if (ids.contains(component.id())) {
                         return false;
@@ -926,7 +943,6 @@ Transaction *PackageKitBackend::installApplication(AbstractResource *app)
 
 Transaction *PackageKitBackend::removeApplication(AbstractResource *app)
 {
-    Q_ASSERT(!isFetching());
     if (!qobject_cast<PackageKitResource *>(app)) {
         Q_EMIT passiveMessage(i18n("Cannot remove '%1'", app->name()));
         return nullptr;
@@ -936,7 +952,7 @@ Transaction *PackageKitBackend::removeApplication(AbstractResource *app)
 
 QSet<AbstractResource *> PackageKitBackend::upgradeablePackages() const
 {
-    if (isFetching() || !m_packagesToAdd.isEmpty()) {
+    if (!m_packagesToAdd.isEmpty()) {
         return {};
     }
 
@@ -985,20 +1001,13 @@ void PackageKitBackend::getUpdatesFinished(PackageKit::Transaction::Exit, uint)
     m_updater->setProgressing(false);
 
     includePackagesToAdd();
-    if (isFetching()) {
-        auto a = new OneTimeAction(
-            [this] {
-                Q_EMIT updatesCountChanged();
-            },
-            this);
-        connect(this, &PackageKitBackend::available, a, &OneTimeAction::trigger);
-    } else {
+    if (!m_isFetching) {
         Q_EMIT updatesCountChanged();
     }
 
     if (!m_updater->isDistroUpgrade() && !PackageKit::Daemon::global()->offline()->upgradeTriggered()) {
         const auto loadDone = [this] {
-            auto nextRelease = AppStreamIntegration::global()->getDistroUpgrade(m_appdata.get());
+            auto nextRelease = AppStreamIntegration::global()->getDistroUpgrade(m_appdata->get());
             if (nextRelease) {
                 foundNewMajorVersion(*nextRelease);
             }
@@ -1006,7 +1015,7 @@ void PackageKitBackend::getUpdatesFinished(PackageKit::Transaction::Exit, uint)
         if (m_appdataLoaded) {
             loadDone();
         } else {
-            connect(m_appdata.get(), &AppStream::Pool::loadFinished, this, loadDone);
+            connect(m_appdata.get(), &AppStream::ConcurrentPool::loadFinished, this, loadDone);
         }
     }
 }
@@ -1137,7 +1146,7 @@ AbstractBackendUpdater *PackageKitBackend::backendUpdater() const
 QVector<AbstractResource *> PackageKitBackend::extendedBy(const QString &id) const
 {
     const auto components = m_appdata->componentsByExtends(id);
-    return resourcesByComponents<QVector<AbstractResource *>>(components);
+    return resourcesByComponents<QVector<AbstractResource *>>(components.result());
 }
 
 AbstractReviewsBackend *PackageKitBackend::reviewsBackend() const
@@ -1179,8 +1188,10 @@ InlineMessage *PackageKitBackend::explainDysfunction() const
     if (!PackageKit::Daemon::isRunning()) {
         return new InlineMessage(InlineMessage::Error,
                                  u"run-build-prune-symbolic"_s,
-                                 i18nc("@info", "The background service (PackageKit) stopped unexpectedly. It may have crashed."),
-                                 m_reportToDistroAction);
+                                 i18nc("@info %2 is the name of the operating system",
+                                       "The PackageKit background service stopped unexpectedly.<nl/></nl/>Please <link url='%1'>report this issue to %2</link>",
+                                       KOSRelease().bugReportUrl(),
+                                       KOSRelease().name()));
     }
 
     return AbstractResourcesBackend::explainDysfunction();
@@ -1191,7 +1202,7 @@ void PackageKitBackend::loadAllPackages()
     if (m_allPackagesLoaded) {
         return;
     }
-    const auto components = m_appdata->components();
+    const auto components = m_appdata->components().result();
     for (const auto &component : components) {
         if (!component.packageNames().isEmpty()) {
             addComponent(component);
